@@ -7,22 +7,23 @@ class MindsDBLexer(Lexer):
     ignore = ' \t\n\r'
 
     tokens = {
-        CREATE, USE, DROP,
+        SELECT, CREATE, SHOW, USE, DROP,
+
+        # Mindsdb special
+        PREDICTOR, PREDICTORS, INTEGRATION, INTEGRATIONS,
+        STREAM, STREAMS, PUBLICATION, PUBLICATIONS,
+
+        LATEST, HORIZON, USING,
+        ENGINE, TRAIN, TEST, PREDICT, MODEL, PARAMETERS,
 
         # SHOW Keywords
 
-        SHOW, SCHEMAS, DATABASES, TABLES, TABLE, FULL, VARIABLES, SESSION, STATUS,
+        SCHEMAS, DATABASES, TABLES, TABLE, FULL, VARIABLES, SESSION, STATUS,
         GLOBAL, PROCEDURE, FUNCTION, INDEX, CREATE, WARNINGS, ENGINES, CHARSET, COLLATION,
-        VIEW, VIEWS, PREDICTOR, PREDICTORS, INTEGRATION, INTEGRATIONS,
-        STREAM, STREAMS, PUBLICATION, PUBLICATIONS,
-
-        # Mindsdb special
-        LATEST,
-
-        ENGINE, TRAIN, TEST, PREDICT, MODEL,
+        VIEW, VIEWS,
 
         # SELECT Keywords
-        WITH, SELECT, DISTINCT, FROM, WHERE, AS,
+        WITH, DISTINCT, FROM, WHERE, AS,
         LIMIT, OFFSET, ASC, DESC, NULLS_FIRST, NULLS_LAST,
         GROUP_BY, HAVING, ORDER_BY,
         STAR,
@@ -53,6 +54,9 @@ class MindsDBLexer(Lexer):
     PREDICT = r'\bPREDICT\b'
     MODEL = r'\bMODEL\b'
     DROP = r'\bDROP\b'
+    PARAMETERS = r'\bPARAMETERS\b'
+    HORIZON = r'\bHORIZON\b'
+    USING = r'\bUSING\b'
 
     # SHOW
 
@@ -85,6 +89,7 @@ class MindsDBLexer(Lexer):
     PUBLICATION = r'\bPUBLICATION\b'
     PUBLICATIONS = r'\bPUBLICATIONS\b'
 
+
     # SELECT
 
     # Keywords
