@@ -9,13 +9,19 @@ class SQLLexer(Lexer):
     tokens = {
         USE,
 
+        # SHOW Keywords
+
+        SHOW, SCHEMAS, DATABASES, TABLES, TABLE, FULL, VARIABLES, SESSION, STATUS,
+        GLOBAL, PROCEDURE, FUNCTION, INDEX, CREATE, WARNINGS, ENGINES, CHARSET, COLLATION,
+
+
         # SELECT Keywords
         WITH, SELECT, DISTINCT, FROM, WHERE, AS,
         LIMIT, OFFSET, ASC, DESC, NULLS_FIRST, NULLS_LAST,
         GROUP_BY, HAVING, ORDER_BY,
         STAR,
 
-        JOIN, INNER_JOIN, OUTER_JOIN, CROSS_JOIN, LEFT_JOIN, RIGHT_JOIN, FULL_JOIN, ON,
+        JOIN, INNER, OUTER, CROSS, LEFT, RIGHT, ON,
 
         UNION, ALL,
 
@@ -31,6 +37,27 @@ class SQLLexer(Lexer):
         # Data types
         CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE}
 
+    # SHOW
+
+    SHOW = r'\bSHOW\b'
+    SCHEMAS = r'\bSCHEMAS\b'
+    DATABASES = r'\bDATABASES\b'
+    TABLES = r'\bTABLES\b'
+    TABLE = r'\bTABLE\b'
+    FULL = r'\bFULL\b'
+    VARIABLES = r'\bVARIABLES\b'
+    SESSION = r'\bSESSION\b'
+    STATUS = r'\STATUS\b'
+    GLOBAL = r'\bGLOBAL\b'
+    PROCEDURE = r'\bPROCEDURE\b'
+    FUNCTION = r'\bFUNCTION\b'
+    INDEX = r'\bINDEX\b'
+    CREATE = r'\bCREATE\b'
+    WARNINGS = r'\bWARNINGS\b'
+    ENGINES = r'\bENGINES\b'
+    CHARSET = r'\bCHARSET\b'
+    COLLATION = r'\bCOLLATION\b'
+
 
     # SELECT
 
@@ -54,12 +81,11 @@ class SQLLexer(Lexer):
     STAR = r'\*'
 
     JOIN = r'\bJOIN\b'
-    INNER_JOIN = r'\bINNER JOIN\b'
-    OUTER_JOIN = r'\bOUTER JOIN\b'
-    CROSS_JOIN = r'\bCROSS JOIN\b'
-    LEFT_JOIN = r'\bLEFT JOIN\b'
-    RIGHT_JOIN = r'\bRIGHT JOIN\b'
-    FULL_JOIN = r'\bFULL JOIN\b'
+    INNER = r'\bINNER\b'
+    OUTER = r'\bOUTER\b'
+    CROSS = r'\bCROSS\b'
+    LEFT = r'\bLEFT\b'
+    RIGHT = r'\bRIGHT\b'
 
     UNION = r'\bUNION\b'
     ALL = r'\bALL\b'
